#include "MIDI_operations.h"
#include <stdint.h>
#include "MIDIUSB.h"
#include "MIDI_inputs.h"
#include <Wire.h>



// First parameter is the event type (0x09 = note on, 0x08 = note off).
// Second parameter is note-on/note-off, combined with the channel.
// Channel can be anything between 0-15. Typically reported to the user as 1-16.
// Third parameter is the note number (48 = middle C).
// Fourth parameter is the velocity (64 = normal, 127 = fastest).


uint8_t decode_note(uint16_t *val)
{
  uint8_t pos = 255;
  #ifdef SHITTY_BUTTONS
  for(uint8_t i = 0; i < sizeof(notes_addr)/sizeof(uint16_t); i++)
    {
        if((*val & NOTES_MASK) == notes_addr[i]) 
          pos = i;
    }
    return pos;
  #else
    for(uint8_t i = 0; i < sizeof(notes_mask)/sizeof(uint16_t); i++)
    {
        if((*val & notes_mask[i]) == notes_addr[i]) 
          pos = i;
    }
    return (pos < 7) ? pos : pos-1;
  #endif
  //if pos == 255 not found, else there's a note.
  //if found -> write on the I2C.
}


void MIDI_send_noteON(uint8_t channel, uint8_t note, uint8_t v)
{
  midiEventPacket_t midi = {0x09, 0x90 | channel, note, v};
  MidiUSB.sendMIDI(midi);
  MidiUSB.flush();
}

void MIDI_send_noteOFF(uint8_t channel, uint8_t note, uint8_t v)
{
  midiEventPacket_t midi = {0x08, 0x80 | channel, note, v};
  MidiUSB.sendMIDI(midi);
  MidiUSB.flush();
}

void MIDI_send_instrument(uint8_t channel, uint8_t instr)
{
  midiEventPacket_t midi = {0x0C, 0xC0 | channel, instr, 0x00};
  MidiUSB.sendMIDI(midi);
  MidiUSB.flush();
}

void MIDI_send_volume(uint8_t channel, uint8_t v)
{
  midiEventPacket_t midi = {0x0B, 0xB0 | channel, 0x07, v};
  MidiUSB.sendMIDI(midi);
  MidiUSB.flush();
}

uint8_t decode_volume(uint8_t pin)
{
  uint16_t v = analogRead(pin)/4;
  if (v < VOLUME_THRESHOLD)
    return 0;
  return (VOLUME_OFFSET + (127*(uint8_t)v)/VOLUME_MAX);
}

uint8_t decode_octave(uint8_t pin)
{
  return !(analogRead(pin) > OCTAVE_THRESHOLD);
}
bool decode_hold(uint8_t val)
{
    return ((val & 0x04)?false:true);
}
